#!/bin/bash

echo "hello from job1" && sleep 5
echo "hello from job2" && sleep 5
echo "hello from job3" && sleep 5
echo "hello from job4" && sleep 5
echo "hello from job5" && sleep 5
echo "hello from job6" && sleep 5
